@@ -19,22 +19,23 @@ import time
 
 from rcsb.utils.io.FileUtil import FileUtil
 from rcsb.utils.io.MarshalUtil import MarshalUtil
+from rcsb.utils.io.StashableBase import StashableBase
 
 logger = logging.getLogger(__name__)
 
 
-class RcsbLigandScoreProvider:
+class RcsbLigandScoreProvider(StashableBase):
     """Accessors for RCSB Ligand quality score supporting data."""
 
     def __init__(self, **kwargs):
-        #
+        dirName = "rcsb-ligand-score"
         self.__cachePath = kwargs.get("cachePath", ".")
-        self.__dirPath = os.path.join(self.__cachePath, "rcsb-ligand-score")
+        super(RcsbLigandScoreProvider, self).__init__(self.__cachePath, [dirName])
+        #
+        self.__dirPath = os.path.join(self.__cachePath, dirName)
         self.__useCache = kwargs.get("useCache", True)
         rcsbLigandScoreUrl = kwargs.get("rcsbLigandScoreUrl", "https://github.com/rcsb/py-rcsb_exdb_assets/raw/development/fall_back/rcsb_ligand_score/ligand_score_reference.csv")
-        rcsbLigandExcludeUrl = kwargs.get(
-            "rcsbLigandExcludeUrl", "https://github.com/rcsb/py-rcsb_exdb_assets/raw/development/fall_back/rcsb_ligand_score/ligand_score_exclude.list"
-        )
+        rcsbLigandExcludeUrl = kwargs.get("rcsbLigandExcludeUrl", "https://github.com/rcsb/py-rcsb_exdb_assets/raw/development/fall_back/rcsb_ligand_score/ligand_score_exclude.list")
         #
         self.__mU = MarshalUtil(workPath=self.__dirPath)
         self.__ligandScoreDL, self.__ligandExcludeD = self.__reload(self.__dirPath, rcsbLigandScoreUrl, rcsbLigandExcludeUrl, self.__useCache)
@@ -46,7 +47,10 @@ class RcsbLigandScoreProvider:
         self.__fitScoreList = None
 
     def testCache(self):
-        return self.__ligandScoreDL and self.__ligandExcludeD
+        if self.__ligandScoreDL and self.__ligandExcludeD:
+            logger.info("Ligand score (%d) exclude (%d)", len(self.__ligandScoreDL), len(self.__ligandExcludeD))
+            return True
+        return False
 
     def getLigandExcludeList(self):
         return list(self.__ligandExcludeD.keys())
@@ -95,7 +99,7 @@ class RcsbLigandScoreProvider:
         #
         if useCache and fU.exists(ligandScoreFilePath) and fU.exists(ligandExcludeFilePath):
             ok = True
-        else:
+        elif not useCache:
             logger.info("Fetching url %s path %s", rcsbLigandScoreUrl, ligandScoreFilePath)
             ok = fU.get(rcsbLigandScoreUrl, ligandScoreFilePath)
             logger.info("Fetching url %s path %s", rcsbLigandExcludeUrl, ligandExcludeFilePath)
